@@ -46,14 +46,10 @@
 #define GEOS_DEBUG 0
 #endif
 
-#ifdef GEOS_DEBUG
+#if GEOS_DEBUG
 #include <iostream>
 #endif
 
-#ifndef GEOS_INLINE
-# include <geos/geom/GeometryFactory.inl>
-#endif
-
 namespace geos {
 namespace geom { // geos::geom
 
@@ -87,7 +83,7 @@ GeometryFactory::GeometryFactory()
 {
 #if GEOS_DEBUG
     std::cerr << "GEOS_DEBUG: GeometryFactory[" << this << "]::GeometryFactory()" << std::endl;
-    std::cerr << "\tcreate PrecisionModel[" << precisionModel << "]" << std::endl;
+    std::cerr << "\tcreate PrecisionModel[" << &precisionModel << "]" << std::endl;
 #endif
 }
 
@@ -469,6 +465,15 @@ GeometryFactory::createLinearRing(CoordinateSequence::Ptr && newCoords) const
     return std::unique_ptr<LinearRing>(new LinearRing(std::move(newCoords), *this));
 }
 
+/*public*/
+std::unique_ptr<LinearRing>
+GeometryFactory::createLinearRing(std::vector<Coordinate> && newCoords)
+const
+{
+    // Can't use make_unique with protected constructor
+    return std::unique_ptr<LinearRing>(new LinearRing(std::move(newCoords), *this));
+}
+
 /*public*/
 LinearRing*
 GeometryFactory::createLinearRing(const CoordinateSequence& fromCoords) const
@@ -643,6 +648,15 @@ const
     return std::unique_ptr<LineString>(new LineString(std::move(newCoords), *this));
 }
 
+/*public*/
+std::unique_ptr<LineString>
+GeometryFactory::createLineString(std::vector<Coordinate> && newCoords)
+const
+{
+    // Can't use make_unique with protected constructor
+    return std::unique_ptr<LineString>(new LineString(std::move(newCoords), *this));
+}
+
 /*public*/
 LineString*
 GeometryFactory::createLineString(const CoordinateSequence& fromCoords)
